@@ -17,7 +17,7 @@
 
 import ssl
 
-from oslo_log import log as logging
+from osprofiler import profiler
 import pymongo
 import pymongo.errors
 
@@ -28,9 +28,6 @@ from zaqar.storage.mongodb import controllers
 from zaqar.storage.mongodb import options
 
 
-LOG = logging.getLogger(__name__)
-
-
 def _connection(conf):
     # NOTE(flaper87): remove possible zaqar specific
     # schemes like: mongodb.fifo
@@ -98,8 +95,16 @@ class DataDriver(storage.DataDriverBase):
         else:
 
             _mongo_wc = conn.write_concern.document.get('w')
-            durable = (_mongo_wc == 'majority' or
-                       _mongo_wc >= 2)
+            # NOTE(flwang): mongo client is using None as the default value of
+            # write concern. But in Python 3.x we can't compare by order
+            # different types of operands like in Python 2.x.
+            # And we can't set the write concern value when create the
+            # connection since it will fail with norepl if mongodb version
+            # below 2.6. Besides it doesn't make sense to create the
+            # connection again after getting the version.
+            durable = (_mongo_wc is not None and
+                       (_mongo_wc == 'majority' or _mongo_wc >= 2)
+                       )
 
             if not self.conf.unreliable and not durable:
                 raise RuntimeError(_('Using a write concern other than '
@@ -180,15 +185,31 @@ class DataDriver(storage.DataDriverBase):
 
     @decorators.lazy_property(write=False)
     def message_controller(self):
-        return controllers.MessageController(self)
+        controller = controllers.MessageController(self)
+        if (self.conf.profiler.enabled and
+                self.conf.profiler.trace_message_store):
+            return profiler.trace_cls("mongodb_message_controller")(controller)
+        else:
+            return controller
 
     @decorators.lazy_property(write=False)
     def claim_controller(self):
-        return controllers.ClaimController(self)
+        controller = controllers.ClaimController(self)
+        if (self.conf.profiler.enabled and
+                self.conf.profiler.trace_message_store):
+            return profiler.trace_cls("mongodb_claim_controller")(controller)
+        else:
+            return controller
 
     @decorators.lazy_property(write=False)
     def subscription_controller(self):
-        return controllers.SubscriptionController(self)
+        controller = controllers.SubscriptionController(self)
+        if (self.conf.profiler.enabled and
+                self.conf.profiler.trace_message_store):
+            return profiler.trace_cls("mongodb_subscription_"
+                                      "controller")(controller)
+        else:
+            return controller
 
 
 class FIFODataDriver(DataDriver):
@@ -202,7 +223,12 @@ class FIFODataDriver(DataDriver):
 
     @decorators.lazy_property(write=False)
     def message_controller(self):
-        return controllers.FIFOMessageController(self)
+        controller = controllers.FIFOMessageController(self)
+        if (self.conf.profiler.enabled and
+                self.conf.profiler.trace_message_store):
+            return profiler.trace_cls("mongodb_message_controller")(controller)
+        else:
+            return controller
 
 
 class ControlDriver(storage.ControlDriverBase):
@@ -241,16 +267,38 @@ class ControlDriver(storage.ControlDriverBase):
 
     @decorators.lazy_property(write=False)
     def queue_controller(self):
-        return controllers.QueueController(self)
+        controller = controllers.QueueController(self)
+        if (self.conf.profiler.enabled and
+                (self.conf.profiler.trace_message_store or
+                    self.conf.profiler.trace_management_store)):
+            return profiler.trace_cls("mongodb_queues_controller")(controller)
+        else:
+            return controller
 
     @property
     def pools_controller(self):
-        return controllers.PoolsController(self)
+        controller = controllers.PoolsController(self)
+        if (self.conf.profiler.enabled and
+                self.conf.profiler.trace_management_store):
+            return profiler.trace_cls("mongodb_pools_controller")(controller)
+        else:
+            return controller
 
     @property
     def catalogue_controller(self):
-        return controllers.CatalogueController(self)
+        controller = controllers.CatalogueController(self)
+        if (self.conf.profiler.enabled and
+                self.conf.profiler.trace_management_store):
+            return profiler.trace_cls("mongodb_catalogue_"
+                                      "controller")(controller)
+        else:
+            return controller
 
     @property
     def flavors_controller(self):
-        return controllers.FlavorsController(self)
+        controller = controllers.FlavorsController(self)
+        if (self.conf.profiler.enabled and
+                self.conf.profiler.trace_management_store):
+            return profiler.trace_cls("mongodb_flavors_controller")(controller)
+        else:
+            return controller
