@@ -24,6 +24,7 @@ Field Mappings:
 import datetime
 import time
 
+from bson import errors as bsonerror
 from bson import objectid
 from oslo_log import log as logging
 from oslo_utils import timeutils
@@ -34,6 +35,7 @@ from zaqar.i18n import _
 from zaqar import storage
 from zaqar.storage import errors
 from zaqar.storage.mongodb import utils
+from zaqar.storage import utils as s_utils
 
 
 LOG = logging.getLogger(__name__)
@@ -135,6 +137,8 @@ class MessageController(storage.Message):
             claim            ->     c
             client uuid      ->     u
             transaction      ->    tx
+            delay            ->     d
+            checksum         ->    cs
     """
 
     def __init__(self, *args, **kwargs):
@@ -230,7 +234,8 @@ class MessageController(storage.Message):
 
     def _list(self, queue_name, project=None, marker=None,
               echo=False, client_uuid=None, projection=None,
-              include_claimed=False, sort=1, limit=None):
+              include_claimed=False, include_delayed=False,
+              sort=1, limit=None):
         """Message document listing helper.
 
         :param queue_name: Name of the queue to list
@@ -248,6 +253,8 @@ class MessageController(storage.Message):
             include or exclude
         :param include_claimed: (Default False) Whether to include
             claimed messages, not just active ones
+        :param include_delayed: (Default False) Whether to include
+            delayed messages, not just active ones
         :param sort: (Default 1) Sort order for the listing. Pass 1 for
             ascending (oldest message first), or -1 for descending (newest
             message first).
@@ -290,6 +297,14 @@ class MessageController(storage.Message):
             # any claim, or are part of an expired claim.
             query['c.e'] = {'$lte': now}
 
+        if not include_delayed:
+            # NOTE(cdyangzhenyu): Only include messages that are not
+            # part of any delay, or are part of an expired delay. if
+            # the message has no attribute 'd', it will also be obtained.
+            # This is for compatibility with old data.
+            query['$or'] = [{'d': {'$lte': now}},
+                            {'d': {'$exists': False}}]
+
         # Construct the request
         cursor = collection.find(query,
                                  projection=projection,
@@ -338,12 +353,12 @@ class MessageController(storage.Message):
 
     def _active(self, queue_name, marker=None, echo=False,
                 client_uuid=None, projection=None, project=None,
-                limit=None):
+                limit=None, include_delayed=False):
 
         return self._list(queue_name, project=project, marker=marker,
                           echo=echo, client_uuid=client_uuid,
                           projection=projection, include_claimed=False,
-                          limit=limit)
+                          include_delayed=include_delayed, limit=limit)
 
     def _claimed(self, queue_name, claim_id,
                  expires=None, limit=None, project=None):
@@ -517,7 +532,8 @@ class MessageController(storage.Message):
 
     def list(self, queue_name, project=None, marker=None,
              limit=storage.DEFAULT_MESSAGES_PER_PAGE,
-             echo=False, client_uuid=None, include_claimed=False):
+             echo=False, client_uuid=None, include_claimed=False,
+             include_delayed=False):
 
         if marker is not None:
             try:
@@ -527,7 +543,8 @@ class MessageController(storage.Message):
 
         messages = self._list(queue_name, project=project, marker=marker,
                               client_uuid=client_uuid, echo=echo,
-                              include_claimed=include_claimed, limit=limit)
+                              include_claimed=include_claimed,
+                              include_delayed=include_delayed, limit=limit)
 
         marker_id = {}
 
@@ -631,24 +648,28 @@ class MessageController(storage.Message):
                                         project,
                                         amount=msgs_n) - msgs_n
 
-        prepared_messages = [
-            {
+        prepared_messages = []
+        for index, message in enumerate(messages):
+            msg = {
                 PROJ_QUEUE: utils.scope_queue_name(queue_name, project),
                 't': message['ttl'],
                 'e': now_dt + datetime.timedelta(seconds=message['ttl']),
                 'u': client_uuid,
                 'c': {'id': None, 'e': now, 'c': 0},
+                'd': now + message.get('delay', 0),
                 'b': message['body'] if 'body' in message else {},
                 'k': next_marker + index,
-                'tx': None,
-            }
+                'tx': None
+                }
+            if self.driver.conf.enable_checksum:
+                msg['cs'] = s_utils.get_checksum(message.get('body', None))
 
-            for index, message in enumerate(messages)
-        ]
+            prepared_messages.append(msg)
 
-        ids = collection.insert(prepared_messages, check_keys=False)
+        res = collection.insert_many(prepared_messages,
+                                     bypass_document_validation=True)
 
-        return [str(id_) for id_ in ids]
+        return [str(id_) for id_ in res.inserted_ids]
 
     @utils.raises_conn_error
     @utils.retries_on_autoreconnect
@@ -808,20 +829,23 @@ class FIFOMessageController(MessageController):
         # Unique transaction ID to facilitate atomic batch inserts
         transaction = objectid.ObjectId()
 
-        prepared_messages = [
-            {
+        prepared_messages = []
+        for index, message in enumerate(messages):
+            msg = {
                 PROJ_QUEUE: utils.scope_queue_name(queue_name, project),
                 't': message['ttl'],
                 'e': now_dt + datetime.timedelta(seconds=message['ttl']),
                 'u': client_uuid,
                 'c': {'id': None, 'e': now, 'c': 0},
+                'd': now + message.get('delay', 0),
                 'b': message['body'] if 'body' in message else {},
                 'k': next_marker + index,
-                'tx': transaction,
-            }
+                'tx': None
+                }
+            if self.driver.conf.enable_checksum:
+                msg['cs'] = s_utils.get_checksum(message.get('body', None))
 
-            for index, message in enumerate(messages)
-        ]
+            prepared_messages.append(msg)
 
         # NOTE(kgriffs): Don't take the time to do a 2-phase insert
         # if there is no way for it to partially succeed.
@@ -838,7 +862,8 @@ class FIFOMessageController(MessageController):
         # before the operation is abandoned is 49.95 seconds.
         for attempt in self._retry_range:
             try:
-                ids = collection.insert(prepared_messages, check_keys=False)
+                res = collection.insert_many(prepared_messages,
+                                             bypass_document_validation=True)
 
                 # Log a message if we retried, for debugging perf issues
                 if attempt != 0:
@@ -849,7 +874,7 @@ class FIFOMessageController(MessageController):
                     LOG.debug(msgtmpl,
                               dict(queue=queue_name,
                                    attempts=attempt + 1,
-                                   num_messages=len(ids),
+                                   num_messages=len(res.inserted_ids),
                                    project=project))
 
                 # Update the counter in preparation for the next batch
@@ -860,7 +885,8 @@ class FIFOMessageController(MessageController):
                 # such that the competing marker's will start at a
                 # unique number, 1 past the max of the messages just
                 # inserted above.
-                self._inc_counter(queue_name, project, amount=len(ids))
+                self._inc_counter(queue_name, project,
+                                  amount=len(res.inserted_ids))
 
                 # NOTE(kgriffs): Finalize the insert once we can say that
                 # all the messages made it. This makes bulk inserts
@@ -871,9 +897,10 @@ class FIFOMessageController(MessageController):
                                            {'$set': {'tx': None}},
                                            upsert=False)
 
-                return [str(id_) for id_ in ids]
+                return [str(id_) for id_ in res.inserted_ids]
 
-            except pymongo.errors.DuplicateKeyError as ex:
+            except (pymongo.errors.DuplicateKeyError,
+                    pymongo.errors.BulkWriteError) as ex:
                 # TODO(kgriffs): Record stats of how often retries happen,
                 # and how many attempts, on average, are required to insert
                 # messages.
@@ -955,7 +982,9 @@ class FIFOMessageController(MessageController):
 
                 for index, message in enumerate(prepared_messages):
                     message['k'] = next_marker + index
-
+            except bsonerror.InvalidDocument as ex:
+                LOG.exception(ex)
+                raise
             except Exception as ex:
                 LOG.exception(ex)
                 raise
@@ -979,14 +1008,18 @@ def _is_claimed(msg, now):
 def _basic_message(msg, now):
     oid = msg['_id']
     age = now - utils.oid_ts(oid)
-
-    return {
+    res = {
         'id': str(oid),
         'age': int(age),
         'ttl': msg['t'],
+        'claim_count': msg['c'].get('c', 0),
         'body': msg['b'],
         'claim_id': str(msg['c']['id']) if msg['c']['id'] else None
-    }
+        }
+    if msg.get('cs'):
+        res['checksum'] = msg.get('cs')
+
+    return res
 
 
 class MessageQueueHandler(object):
