@@ -27,6 +27,7 @@ from zaqar.storage.redis import options
 REDIS_DEFAULT_PORT = 6379
 SENTINEL_DEFAULT_PORT = 26379
 DEFAULT_SOCKET_TIMEOUT = 0.1
+DEFAULT_DBID = 0
 
 STRATEGY_TCP = 1
 STRATEGY_UNIX = 2
@@ -52,6 +53,13 @@ class ConnectionURI(object):
             path, sep, query = path.partition('?')
         else:
             query = parsed_url.query
+        # NOTE(gengchc2): Redis connection support password configure.
+        self.password = None
+        if '@' in path:
+            self.password, sep, path = path.partition('@')
+        netloc = parsed_url.netloc
+        if '@' in netloc:
+            self.password, sep, netloc = netloc.partition('@')
 
         query_params = dict(urllib.parse.parse_qsl(query))
 
@@ -59,6 +67,7 @@ class ConnectionURI(object):
         self.strategy = None
         self.socket_timeout = float(query_params.get('socket_timeout',
                                                      DEFAULT_SOCKET_TIMEOUT))
+        self.dbid = int(query_params.get('dbid', DEFAULT_DBID))
 
         # TCP
         self.port = None
@@ -78,7 +87,7 @@ class ConnectionURI(object):
 
             # NOTE(kgriffs): Have to parse list of sentinel hosts ourselves
             # since urllib doesn't support it.
-            for each_host in parsed_url.netloc.split(','):
+            for each_host in netloc.split(','):
                 name, sep, port = each_host.partition(':')
 
                 if port:
@@ -99,8 +108,8 @@ class ConnectionURI(object):
                         'sentinel hosts')
                 raise errors.ConfigurationError(msg)
 
-        elif parsed_url.netloc:
-            if ',' in parsed_url.netloc:
+        elif netloc:
+            if ',' in netloc:
                 # NOTE(kgriffs): They probably were specifying
                 # a list of sentinel hostnames, but forgot to
                 # add 'master' to the query string.
@@ -256,15 +265,31 @@ class ControlDriver(storage.ControlDriverBase):
 
     @property
     def pools_controller(self):
-        raise NotImplementedError()
+        controller = controllers.PoolsController(self)
+        if (self.conf.profiler.enabled and
+                self.conf.profiler.trace_management_store):
+            return profiler.trace_cls("redis_pools_controller")(controller)
+        else:
+            return controller
 
     @property
     def catalogue_controller(self):
-        raise NotImplementedError()
+        controller = controllers.CatalogueController(self)
+        if (self.conf.profiler.enabled and
+                self.conf.profiler.trace_management_store):
+            return profiler.trace_cls("redis_catalogue_"
+                                      "controller")(controller)
+        else:
+            return controller
 
     @property
     def flavors_controller(self):
-        raise NotImplementedError()
+        controller = controllers.FlavorsController(self)
+        if (self.conf.profiler.enabled and
+                self.conf.profiler.trace_management_store):
+            return profiler.trace_cls("redis_flavors_controller")(controller)
+        else:
+            return controller
 
 
 def _get_redis_client(driver):
@@ -274,6 +299,8 @@ def _get_redis_client(driver):
     if connection_uri.strategy == STRATEGY_SENTINEL:
         sentinel = redis.sentinel.Sentinel(
             connection_uri.sentinels,
+            db=connection_uri.dbid,
+            password=connection_uri.password,
             socket_timeout=connection_uri.socket_timeout)
 
         # NOTE(prashanthr_): The socket_timeout parameter being generic
@@ -285,8 +312,12 @@ def _get_redis_client(driver):
         return redis.StrictRedis(
             host=connection_uri.hostname,
             port=connection_uri.port,
+            db=connection_uri.dbid,
+            password=connection_uri.password,
             socket_timeout=connection_uri.socket_timeout)
     else:
         return redis.StrictRedis(
             unix_socket_path=connection_uri.unix_socket_path,
+            db=connection_uri.dbid,
+            password=connection_uri.password,
             socket_timeout=connection_uri.socket_timeout)
