@@ -25,6 +25,7 @@ from zaqar.storage import errors
 from zaqar.storage.redis import models
 from zaqar.storage.redis import scripting
 from zaqar.storage.redis import utils
+from zaqar.storage import utils as s_utils
 
 Message = models.Message
 MessageEnvelope = models.MessageEnvelope
@@ -96,6 +97,10 @@ class MessageController(storage.Message, scripting.Mixin):
         +---------------------+---------+
         |  created time       |  cr     |
         +---------------------+---------+
+        |  delay expiry time  |  d      |
+        +---------------------+---------+
+        |  body checksum      |  cs      |
+        +---------------------+---------+
 
     4. Messages rank counter (Redis Hash):
 
@@ -223,7 +228,7 @@ class MessageController(storage.Message, scripting.Mixin):
     def _list(self, queue, project=None, marker=None,
               limit=storage.DEFAULT_MESSAGES_PER_PAGE,
               echo=False, client_uuid=None,
-              include_claimed=False,
+              include_claimed=False, include_delayed=False,
               to_basic=True):
 
         if not self._queue_ctrl.exists(queue, project):
@@ -262,6 +267,10 @@ class MessageController(storage.Message, scripting.Mixin):
             filters.append(functools.partial(utils.msg_claimed_filter,
                                              now=now))
 
+        if not include_delayed:
+            filters.append(functools.partial(utils.msg_delayed_filter,
+                                             now=now))
+
         if not echo:
             filters.append(functools.partial(utils.msg_echo_filter,
                                              client_uuid=client_uuid))
@@ -344,10 +353,11 @@ class MessageController(storage.Message, scripting.Mixin):
     def list(self, queue, project=None, marker=None,
              limit=storage.DEFAULT_MESSAGES_PER_PAGE,
              echo=False, client_uuid=None,
-             include_claimed=False):
+             include_claimed=False, include_delayed=False):
 
         return self._list(queue, project, marker, limit, echo,
-                          client_uuid, include_claimed)
+                          client_uuid, include_claimed,
+                          include_delayed)
 
     @utils.raises_conn_error
     @utils.retries_on_connection_error
@@ -409,7 +419,6 @@ class MessageController(storage.Message, scripting.Mixin):
 
         message_ids = []
         now = timeutils.utcnow_ts()
-
         with self._client.pipeline() as pipe:
             for msg in messages:
                 prepared_msg = Message(
@@ -419,7 +428,10 @@ class MessageController(storage.Message, scripting.Mixin):
                     claim_id=None,
                     claim_expires=now,
                     claim_count=0,
+                    delay_expires=now + msg.get('delay', 0),
                     body=msg.get('body', {}),
+                    checksum=s_utils.get_checksum(msg.get('body', None)) if
+                    self.driver.conf.enable_checksum else None
                 )
 
                 prepared_msg.to_redis(pipe)
