@@ -15,7 +15,6 @@
 import functools
 
 import msgpack
-from oslo_log import log as logging
 from oslo_utils import timeutils
 import redis
 
@@ -24,8 +23,6 @@ from zaqar import storage
 from zaqar.storage import errors
 from zaqar.storage.redis import utils
 
-LOG = logging.getLogger(__name__)
-
 QUEUES_SET_STORE_NAME = 'queues_set'
 MESSAGE_IDS_SUFFIX = 'messages'
 
@@ -111,7 +108,10 @@ class QueueController(storage.Queue):
 
     def _get(self, name, project=None):
         """Obtain the metadata from the queue."""
-        return self.get_metadata(name, project)
+        try:
+            return self.get_metadata(name, project)
+        except errors.QueueDoesNotExist:
+            return {}
 
     @utils.raises_conn_error
     def _create(self, name, metadata=None, project=None):
