@@ -13,17 +13,15 @@
 # License for the specific language governing permissions and limitations under
 # the License.
 
+from oslo_db.sqlalchemy import engines
 from osprofiler import profiler
 from osprofiler import sqlalchemy as sa_tracer
 import sqlalchemy as sa
-from sqlalchemy.orm import scoped_session
-from sqlalchemy.orm import sessionmaker
 
 from zaqar.common import decorators
 from zaqar import storage
 from zaqar.storage.sqlalchemy import controllers
 from zaqar.storage.sqlalchemy import options
-from zaqar.storage.sqlalchemy import tables
 
 
 class ControlDriver(storage.ControlDriverBase):
@@ -34,11 +32,6 @@ class ControlDriver(storage.ControlDriverBase):
                                 group=options.MANAGEMENT_SQLALCHEMY_GROUP)
         self.sqlalchemy_conf = self.conf[options.MANAGEMENT_SQLALCHEMY_GROUP]
 
-    def _sqlite_on_connect(self, conn, record):
-        # NOTE(flaper87): This is necessary in order
-        # to ensure FK are treated correctly by sqlite.
-        conn.execute('pragma foreign_keys=ON')
-
     def _mysql_on_connect(self, conn, record):
         # NOTE(flaper87): This is necessary in order
         # to ensure that all date operations in mysql
@@ -46,23 +39,19 @@ class ControlDriver(storage.ControlDriverBase):
         conn.query('SET time_zone = "+0:00"')
 
     @decorators.lazy_property(write=False)
-    def engine(self, *args, **kwargs):
+    def engine(self):
         uri = self.sqlalchemy_conf.uri
-        engine = sa.create_engine(uri, **kwargs)
-
-        # TODO(flaper87): Find a better way
-        # to do this.
-        if uri.startswith('sqlite://'):
-            sa.event.listen(engine, 'connect',
-                            self._sqlite_on_connect)
+        engine = engines.create_engine(uri, sqlite_fk=True)
 
         if (uri.startswith('mysql://') or
                 uri.startswith('mysql+pymysql://')):
+            # oslo_db.create_engine makes a test connection, throw that out
+            # first.   mysql time_zone can be added to oslo_db as a
+            # startup option
+            engine.dispose()
             sa.event.listen(engine, 'connect',
                             self._mysql_on_connect)
 
-        tables.metadata.create_all(engine, checkfirst=True)
-
         if (self.conf.profiler.enabled and
                 self.conf.profiler.trace_message_store):
             sa_tracer.add_tracing(sa, engine, "db")
@@ -73,18 +62,11 @@ class ControlDriver(storage.ControlDriverBase):
     # that acquires the connection to the DB for the desired scope and
     # closes it once the operations are completed
     # TODO(wangxiyuan): we should migrate to oslo.db asap.
-    @decorators.lazy_property(write=False)
-    def connection(self):
-        # use scoped_session to avoid multi-threading problem.
-        session = scoped_session(sessionmaker(bind=self.engine,
-                                              autocommit=True))
-        return session()
-
     def run(self, *args, **kwargs):
-        return self.connection.execute(*args, **kwargs)
+        return self.engine.execute(*args, **kwargs)
 
     def close(self):
-        self.connection.close()
+        pass
 
     @property
     def pools_controller(self):
