@@ -12,6 +12,7 @@
 # limitations under the License.
 
 import copy
+import datetime
 import functools
 import uuid
 
@@ -23,6 +24,7 @@ from zaqar.common import decorators
 from zaqar import storage
 from zaqar.storage import errors
 from zaqar.storage.swift import utils
+from zaqar.storage import utils as s_utils
 
 
 class MessageController(storage.Message):
@@ -48,8 +50,12 @@ class MessageController(storage.Message):
        +--------------+-----------------------------------------+
        | Claim ID     | Object content 'claim_id'               |
        +--------------+-----------------------------------------+
+       | Delay Expires| Object content 'delay_expires'          |
+       +--------------+-----------------------------------------+
        | Expires      | Object Delete-After header              |
        +--------------------------------------------------------+
+       | Checksum     | Object content 'body' checksum          |
+       +--------------------------------------------------------+
     """
 
     def __init__(self, *args, **kwargs):
@@ -89,7 +95,8 @@ class MessageController(storage.Message):
     def _list(self, queue, project=None, marker=None,
               limit=storage.DEFAULT_MESSAGES_PER_PAGE,
               echo=False, client_uuid=None,
-              include_claimed=False, sort=1):
+              include_claimed=False, include_delayed=False,
+              sort=1):
         """List messages in the queue, oldest first(ish)
 
         Time ordering and message inclusion in lists are soft, there is no
@@ -127,6 +134,12 @@ class MessageController(storage.Message):
                 queue, msg['claim_id'], project)
             return claim_obj is not None and claim_obj['ttl'] > 0
 
+        def is_delayed(msg, headers):
+            if include_delayed:
+                return False
+            now = timeutils.utcnow_ts()
+            return msg.get('delay_expires', 0) > now
+
         def is_echo(msg, headers):
             if echo:
                 return False
@@ -135,6 +148,7 @@ class MessageController(storage.Message):
         filters = [
             is_echo,
             is_claimed,
+            is_delayed,
         ]
         marker = {}
         get_object = functools.partial(client.get_object, container)
@@ -148,9 +162,9 @@ class MessageController(storage.Message):
     def list(self, queue, project=None, marker=None,
              limit=storage.DEFAULT_MESSAGES_PER_PAGE,
              echo=False, client_uuid=None,
-             include_claimed=False):
+             include_claimed=False, include_delayed=False,):
         return self._list(queue, project, marker, limit, echo,
-                          client_uuid, include_claimed)
+                          client_uuid, include_claimed, include_delayed)
 
     def first(self, queue, project=None, sort=1):
         if sort not in (1, -1):
@@ -211,34 +225,24 @@ class MessageController(storage.Message):
 
     def _create_msg(self, queue, msg, client_uuid, project):
         slug = str(uuid.uuid1())
-        contents = jsonutils.dumps(
-            {'body': msg.get('body', {}), 'claim_id': None,
-             'ttl': msg['ttl'], 'claim_count': 0})
-        try:
-            self._client.put_object(
-                utils._message_container(queue, project),
-                slug,
-                contents=contents,
-                content_type='application/json',
-                headers={
-                    'x-object-meta-clientid': str(client_uuid),
-                    'x-delete-after': msg['ttl']})
-        except swiftclient.ClientException as exc:
-            # NOTE(flwang): To avoid check the queue existence each time when
-            # posting messages, let's catch the 404 and create the 'queue'
-            # on demand.
-            if exc.http_status == 404:
-                self._client.put_container(utils._message_container(queue,
-                                                                    project))
-                self._client.put_object(
-                    utils._message_container(queue, project),
-                    slug,
-                    contents=contents,
-                    content_type='application/json',
-                    headers={
-                        'x-object-meta-clientid': str(client_uuid),
-                        'x-delete-after': msg['ttl']})
+        now = timeutils.utcnow_ts()
+        message = {'body': msg.get('body', {}), 'claim_id': None,
+                   'ttl': msg['ttl'], 'claim_count': 0,
+                   'delay_expires': now + msg.get('delay', 0)}
 
+        if self.driver.conf.enable_checksum:
+            message['checksum'] = s_utils.get_checksum(msg.get('body', None))
+
+        contents = jsonutils.dumps(message)
+        utils._put_or_create_container(
+            self._client,
+            utils._message_container(queue, project),
+            slug,
+            contents=contents,
+            content_type='application/json',
+            headers={
+                'x-object-meta-clientid': str(client_uuid),
+                'x-delete-after': msg['ttl']})
         return slug
 
     def delete(self, queue, message_id, project=None, claim=None):
@@ -341,10 +345,12 @@ class MessageQueueHandler(object):
                     raise
             else:
                 created = float(headers['x-timestamp'])
+                created_iso = datetime.datetime.utcfromtimestamp(
+                    created).strftime('%Y-%m-%dT%H:%M:%SZ')
                 newest = {
                     'id': obj['name'],
                     'age': now - created,
-                    'created': timeutils.iso8601_from_timestamp(created)}
+                    'created': created_iso}
                 if oldest is None:
                     oldest = copy.deepcopy(newest)
                 total += 1
