@@ -24,7 +24,10 @@ import six
 
 from zaqar.api.v1 import response as response_v1
 from zaqar.api.v1_1 import response as response_v1_1
+from zaqar.api.v2 import response as response_v2
 from zaqar import bootstrap
+from zaqar.storage import mongodb
+from zaqar.storage.redis import driver as redis
 from zaqar import tests as testing
 from zaqar.tests.functional import config
 from zaqar.tests.functional import helpers
@@ -50,6 +53,11 @@ class FunctionalTestBase(testing.TestBase):
     server = None
     server_class = None
     config_file = None
+    class_bootstrap = None
+    # NOTE(Eva-i): ttl_gc_interval is the known maximum time interval between
+    # automatic resource TTL expirations. Depends on message store back end.
+    class_ttl_gc_interval = None
+    wipe_dbs_projects = set([])
 
     def setUp(self):
         super(FunctionalTestBase, self).setUp()
@@ -75,16 +83,22 @@ class FunctionalTestBase(testing.TestBase):
 
         self.resource_defaults = transport_base.ResourceDefaults(self.mconf)
 
-        if _TEST_INTEGRATION:
-            # TODO(kgriffs): This code should be replaced to use
-            # an external wsgi server instance.
+        # Always register options
+        self.__class__.class_bootstrap = bootstrap.Bootstrap(self.mconf)
+        self.class_bootstrap.transport
 
-            # NOTE(flaper87): Use running instances.
-            if self.cfg.zaqar.run_server:
-                if not (self.server and self.server.is_alive()):
-                    self.server = self.server_class()
-                    self.server.start(self.mconf)
-                    self.addCleanup(self.server.process.terminate)
+        datadriver = self.class_bootstrap.storage._storage
+        if isinstance(datadriver, redis.DataDriver):
+            self.__class__.class_ttl_gc_interval = 1
+        if isinstance(datadriver, mongodb.DataDriver):
+            # NOTE(kgriffs): MongoDB's TTL scavenger only runs once a minute
+            self.__class__.class_ttl_gc_interval = 60
+
+        if _TEST_INTEGRATION:
+            if not (self.server and self.server.is_alive()):
+                self.server = self.server_class()
+                self.server.start(self.mconf)
+                self.addCleanup(self.server.process.terminate)
 
             self.client = http.Client()
         else:
@@ -92,21 +106,111 @@ class FunctionalTestBase(testing.TestBase):
                 self.mconf.pooling = True
                 self.mconf.admin_mode = True
 
-            boot = bootstrap.Bootstrap(self.mconf)
-            self.addCleanup(boot.storage.close)
-            self.addCleanup(boot.control.close)
-            self.client = http.WSGIClient(boot.transport.app)
+            self.addCleanup(self.class_bootstrap.storage.close)
+            self.addCleanup(self.class_bootstrap.control.close)
+            self.client = http.WSGIClient(self.class_bootstrap.transport.app)
 
         self.headers = helpers.create_zaqar_headers(self.cfg)
 
-        if self.cfg.auth.auth_on:
-            auth_token = helpers.get_keystone_token(self.cfg, self.client)
-            self.headers["X-Auth-Token"] = auth_token
-
         self.headers_response_with_body = {'location', 'content-type'}
 
         self.client.set_headers(self.headers)
 
+        # Store information required for cleaning databases after
+        # execution of test class
+        self.wipe_dbs_projects.add(self.headers["X-Project-ID"])
+
+    def tearDown(self):
+        super(FunctionalTestBase, self).tearDown()
+        # Project might has changed during test case execution.
+        # Lets add it again to the set.
+        self.wipe_dbs_projects.add(self.headers["X-Project-ID"])
+
+    @staticmethod
+    def _if_mongo_datadriver_drop_dbs(driver):
+        """Drops MongoDB datadriver's databases.
+
+        :param driver: instance of zaqar.storage.mongodb.driver.DataDriver
+        """
+        if not isinstance(driver, mongodb.DataDriver):
+            return
+        for db in driver.message_databases:
+            driver.connection.drop_database(db)
+        subscription_db = driver.subscriptions_database
+        driver.connection.drop_database(subscription_db)
+
+    @staticmethod
+    def _if_mongo_controldriver_drop_dbs(driver):
+        """Drops all MongoDB controldriver's databases.
+
+        :param driver: instance of zaqar.storage.mongodb.driver.ControlDriver
+        """
+        if not isinstance(driver, mongodb.ControlDriver):
+            return
+        driver.connection.drop_database(driver.database)
+        driver.connection.drop_database(driver.queues_database)
+
+    @classmethod
+    def _pooling_drop_dbs_by_project(cls, xproject):
+        """Finds all pool drivers by project, drops all their databases.
+
+        Assumes that pooling is enabled.
+
+        :param xproject: project name to use for pool drivers search
+        """
+        datadriver = cls.class_bootstrap.storage._storage
+        controldriver = cls.class_bootstrap.control
+        # Let's get list of all queues by project
+        queue_generator = controldriver.queue_controller.list(project=xproject)
+        queues = list(next(queue_generator))
+        # Let's extract all queue names from the list of queues
+        queue_names = [q['name'] for q in queues]
+        # Finally let's use queues names to get each one of pool datadrivers
+        catalog = datadriver._pool_catalog
+        for queue_name in queue_names:
+            pool_pipe_driver = catalog.lookup(queue_name, project=xproject)
+            pool_datadriver = pool_pipe_driver._storage
+            if pool_datadriver is not None:
+                # Let's delete the queue, so the next invocation of
+                # pooling_catalog.lookup() will not recreate pool driver
+                controldriver.queue_controller.delete(queue_name)
+                # Let's drop pool's databases
+                cls._if_mongo_datadriver_drop_dbs(pool_datadriver)
+
+    @classmethod
+    def tearDownClass(cls):
+        """Cleans up after test class execution.
+
+        Drops all databases left.
+        Closes connections to databases.
+        """
+        # Bootstrap can be None if all test cases were skipped, so nothing to
+        # clean
+        if cls.class_bootstrap is None:
+            return
+
+        datadriver = cls.class_bootstrap.storage._storage
+        controldriver = cls.class_bootstrap.control
+
+        if cls.class_bootstrap.conf.pooling:
+            # Pooling detected, let's drop pooling-specific databases
+            for p in cls.wipe_dbs_projects:
+                # This will find all pool databases by project and drop them
+                cls._pooling_drop_dbs_by_project(p)
+            controldriver.pools_controller.drop_all()
+            controldriver.flavors_controller.drop_all()
+        else:
+            # No pooling detected, let's just drop datadriver's databases
+            cls._if_mongo_datadriver_drop_dbs(datadriver)
+
+        cls.class_bootstrap.storage.close()
+
+        # Let's drop controldriver's databases
+        controldriver.catalogue_controller.drop_all()
+        cls._if_mongo_controldriver_drop_dbs(controldriver)
+
+        controldriver.close()
+
     def assertIsSubset(self, required_values, actual_values):
         """Checks if a list is subset of another.
 
@@ -126,7 +230,7 @@ class FunctionalTestBase(testing.TestBase):
         """
         msg = ('More Messages returned than allowed: expected count = {0}'
                ', actual count = {1}'.format(expectedCount, actualCount))
-        self.assertTrue(actualCount <= expectedCount, msg)
+        self.assertLessEqual(actualCount, expectedCount, msg)
 
     def assertQueueStats(self, result_json, claimed):
         """Checks the Queue Stats results
@@ -137,11 +241,9 @@ class FunctionalTestBase(testing.TestBase):
         total = self.limits.max_messages_per_claim_or_pop
         free = total - claimed
 
-        self.assertEqual(result_json['messages']['claimed'], claimed)
-        self.assertEqual(result_json['messages']['free'],
-                         free)
-        self.assertEqual(result_json['messages']['total'],
-                         total)
+        self.assertEqual(claimed, result_json['messages']['claimed'])
+        self.assertEqual(free, result_json['messages']['free'])
+        self.assertEqual(total, result_json['messages']['total'])
 
         if 'oldest' in result_json['messages']:
             oldest_message = result_json['messages']['oldest']
@@ -174,17 +276,18 @@ class FunctionalTestBase(testing.TestBase):
 
         response_keys = message.keys()
         response_keys = sorted(response_keys)
-        self.assertEqual(response_keys, expected_keys)
+        self.assertEqual(expected_keys, response_keys)
 
         # Verify that age has valid values
         age = message['age']
-        self.assertTrue(0 <= age <= self.limits.max_message_ttl,
-                        msg='Invalid Age {0}'.format(age))
+        msg = 'Invalid Age {0}'.format(age)
+        self.assertLessEqual(0, age, msg)
+        self.assertLessEqual(age, self.limits.max_message_ttl, msg)
 
         # Verify that GET on href returns 200
         path = message['href']
         result = self.client.get(path)
-        self.assertEqual(result.status_code, 200)
+        self.assertEqual(200, result.status_code)
 
         # Verify that created time falls within the last 10 minutes
         # NOTE(malini): The messages are created during the test.
@@ -201,7 +304,8 @@ class FunctionalTestBase(testing.TestBase):
 
         msg = ('Invalid Time Delta {0}, Created time {1}, Now {2}'
                .format(delta, created_time, now))
-        self.assertTrue(0 <= delta <= 6000, msg)
+        self.assertLessEqual(0, delta, msg)
+        self.assertLessEqual(delta, 6000, msg)
 
 
 @six.add_metaclass(abc.ABCMeta)
@@ -297,3 +401,9 @@ class V1_1FunctionalTestBase(FunctionalTestBase):
     def setUp(self):
         super(V1_1FunctionalTestBase, self).setUp()
         self.response = response_v1_1.ResponseSchema(self.limits)
+
+
+class V2FunctionalTestBase(FunctionalTestBase):
+    def setUp(self):
+        super(V2FunctionalTestBase, self).setUp()
+        self.response = response_v2.ResponseSchema(self.limits)
