@@ -14,18 +14,20 @@
 # limitations under the License.
 
 import json
-import uuid
 
+import ddt
 from keystonemiddleware import auth_token
 import mock
 
+from oslo_utils import uuidutils
+from zaqar.common import consts
 from zaqar.common import urls
 from zaqar.tests.unit.transport.websocket import base
 from zaqar.tests.unit.transport.websocket import utils as test_utils
 
 
+@ddt.ddt
 class AuthTest(base.V2Base):
-
     config_file = "websocket_mongodb_keystone_auth.conf"
 
     def setUp(self):
@@ -37,7 +39,7 @@ class AuthTest(base.V2Base):
 
         self.project_id = '7e55e1a7e'
         self.headers = {
-            'Client-ID': str(uuid.uuid4()),
+            'Client-ID': uuidutils.generate_uuid(),
             'X-Project-ID': self.project_id
         }
         auth_mock = mock.patch.object(auth_token.AuthProtocol, '__call__')
@@ -66,6 +68,18 @@ class AuthTest(base.V2Base):
         self.assertEqual(1, len(responses))
         self.assertEqual('200 OK', responses[0])
 
+        # Check that the env is available to future requests
+        req = json.dumps({'action': consts.MESSAGE_LIST,
+                          'body': {'queue_name': 'myqueue'},
+                          'headers': self.headers})
+        process_request = mock.patch.object(self.protocol._handler,
+                                            'process_request').start()
+        process_request.return_value = self.protocol._handler.create_response(
+            200, {})
+        self.protocol.onMessage(req, False)
+        self.assertEqual(1, process_request.call_count)
+        self.assertEqual(self.env, process_request.call_args[0][0]._env)
+
     def test_post_between_auth(self):
         headers = self.headers.copy()
         headers['X-Auth-Token'] = 'mytoken1'
@@ -76,22 +90,23 @@ class AuthTest(base.V2Base):
         msg_mock = msg_mock.start()
         self.protocol.onMessage(req, False)
 
-        req = test_utils.create_request("queue_list", {}, self.headers)
+        req = test_utils.create_request(consts.QUEUE_LIST, {}, self.headers)
         self.protocol.onMessage(req, False)
 
         self.assertEqual(1, msg_mock.call_count)
         resp = json.loads(msg_mock.call_args[0][0])
-        self.assertEqual(resp['headers']['status'], 403)
+        self.assertEqual(403, resp['headers']['status'])
 
     def test_failed_auth(self):
         msg_mock = mock.patch.object(self.protocol, 'sendMessage')
         self.addCleanup(msg_mock.stop)
         msg_mock = msg_mock.start()
+        self.protocol._auth_in_binary = False
         self.protocol._auth_response('401 error', 'Failed')
         self.assertEqual(1, msg_mock.call_count)
         resp = json.loads(msg_mock.call_args[0][0])
-        self.assertEqual(resp['headers']['status'], 401)
-        self.assertEqual(resp['request']['action'], 'authenticate')
+        self.assertEqual(401, resp['headers']['status'])
+        self.assertEqual('authenticate', resp['request']['action'])
 
     def test_reauth(self):
         headers = self.headers.copy()
@@ -122,6 +137,53 @@ class AuthTest(base.V2Base):
         self.assertIn('cancelled', repr(handle))
         self.assertNotIn('cancelled', repr(self.protocol._deauth_handle))
 
+    def test_reauth_after_auth_failure(self):
+        headers = self.headers.copy()
+        headers['X-Auth-Token'] = 'wrong_token'
+        req = json.dumps({'action': 'authenticate', 'headers': headers})
+
+        msg_mock = mock.patch.object(self.protocol, 'sendMessage')
+        self.addCleanup(msg_mock.stop)
+        msg_mock = msg_mock.start()
+        # after authenticate failure, the _auth_app will be  None and the
+        # request will raise 401 error.
+        self.protocol.onMessage(req, False)
+        self.protocol._auth_response('401 error', 'Failed')
+        resp = json.loads(msg_mock.call_args[0][0])
+
+        self.assertEqual(401, resp['headers']['status'])
+        self.assertEqual('authenticate', resp['request']['action'])
+        self.assertIsNone(self.protocol._auth_app)
+
+        # try to authenticate again, "onMessage" should not return 403 because
+        # that the _auth_app was cleaned after auth failure.
+        headers['X-Auth-Token'] = 'mytoken'
+        req = json.dumps({'action': 'authenticate', 'headers': headers})
+        self.protocol.onMessage(req, False)
+
+        self.protocol._auth_response('200 OK', 'authenticate success')
+        resp = json.loads(msg_mock.call_args[0][0])
+        self.assertEqual(200, resp['headers']['status'])
+
+    @ddt.data(True, False)
+    def test_auth_response_serialization_format(self, in_binary):
+        dumps, loads, create_req = test_utils.get_pack_tools(binary=in_binary)
+        headers = self.headers.copy()
+        headers['X-Auth-Token'] = 'mytoken1'
+        req = create_req("authenticate", {}, headers)
+
+        msg_mock = mock.patch.object(self.protocol, 'sendMessage')
+        self.addCleanup(msg_mock.stop)
+        msg_mock = msg_mock.start()
+        # Depending on onMessage method's second argument, auth response should
+        # be in binary or text format.
+        self.protocol.onMessage(req, in_binary)
+        self.assertEqual(in_binary, self.protocol._auth_in_binary)
+        self.protocol._auth_response('401 error', 'Failed')
+        self.assertEqual(1, msg_mock.call_count)
+        resp = loads(msg_mock.call_args[0][0])
+        self.assertEqual(401, resp['headers']['status'])
+
     def test_signed_url(self):
         send_mock = mock.Mock()
         self.protocol.sendMessage = send_mock
@@ -137,7 +199,7 @@ class AuthTest(base.V2Base):
             'URL-Methods': ['GET'],
             'URL-Paths': ['/v2/queues/myqueue/messages']
         })
-        req = json.dumps({'action': 'message_list',
+        req = json.dumps({'action': consts.MESSAGE_LIST,
                           'body': {'queue_name': 'myqueue'},
                           'headers': headers})
         self.protocol.onMessage(req, False)
@@ -161,7 +223,7 @@ class AuthTest(base.V2Base):
             'URL-Methods': ['GET'],
             'URL-Paths': ['/v2/queues/otherqueue/messages']
         })
-        req = json.dumps({'action': 'message_list',
+        req = json.dumps({'action': consts.MESSAGE_LIST,
                           'body': {'queue_name': 'otherqueue'},
                           'headers': headers})
         self.protocol.onMessage(req, False)
@@ -185,7 +247,7 @@ class AuthTest(base.V2Base):
             'URL-Methods': ['GET'],
             'URL-Paths': ['/v2/queues/myqueue/messages']
         })
-        req = json.dumps({'action': 'message_delete',
+        req = json.dumps({'action': consts.MESSAGE_DELETE,
                           'body': {'queue_name': 'myqueue',
                                    'message_id': '123'},
                           'headers': headers})
