@@ -13,11 +13,11 @@
 # the License.
 
 import contextlib
-import uuid
 
 import ddt
 import falcon
 from oslo_serialization import jsonutils
+from oslo_utils import uuidutils
 
 from zaqar import tests as testing
 from zaqar.tests.unit.transport.wsgi import base
@@ -38,7 +38,7 @@ def pool(test, name, weight, uri, options={}):
     :returns: (name, weight, uri, options)
     :rtype: see above
     """
-    uri = "%s/%s" % (uri, str(uuid.uuid4()))
+    uri = "%s/%s" % (uri, uuidutils.generate_uuid())
     doc = {'weight': weight, 'uri': uri, 'options': options}
     path = test.url_prefix + '/pools/' + name
 
@@ -63,12 +63,13 @@ def pools(test, count, uri):
     :returns: (paths, weights, uris, options)
     :rtype: ([six.text_type], [int], [six.text_type], [dict])
     """
+    mongo_url = uri
     base = test.url_prefix + '/pools/'
     args = [(base + str(i), i,
              {str(i): i})
             for i in range(count)]
     for path, weight, option in args:
-        uri = "%s/%s" % (uri, str(uuid.uuid4()))
+        uri = "%s/%s" % (mongo_url, uuidutils.generate_uuid())
         doc = {'weight': weight, 'uri': uri, 'options': option}
         test.simulate_put(path, body=jsonutils.dumps(doc))
 
@@ -88,83 +89,83 @@ class TestPoolsMongoDB(base.V1Base):
     def setUp(self):
         super(TestPoolsMongoDB, self).setUp()
         self.doc = {'weight': 100, 'uri': self.mongodb_url}
-        self.pool = self.url_prefix + '/pools/' + str(uuid.uuid1())
+        self.pool = self.url_prefix + '/pools/' + uuidutils.generate_uuid()
         self.simulate_put(self.pool, body=jsonutils.dumps(self.doc))
-        self.assertEqual(self.srmock.status, falcon.HTTP_201)
+        self.assertEqual(falcon.HTTP_201, self.srmock.status)
 
     def tearDown(self):
         super(TestPoolsMongoDB, self).tearDown()
         self.simulate_delete(self.pool)
-        self.assertEqual(self.srmock.status, falcon.HTTP_204)
+        self.assertEqual(falcon.HTTP_204, self.srmock.status)
 
     def test_put_pool_works(self):
-        name = str(uuid.uuid1())
+        name = uuidutils.generate_uuid()
         weight, uri = self.doc['weight'], self.doc['uri']
         with pool(self, name, weight, uri):
-            self.assertEqual(self.srmock.status, falcon.HTTP_201)
+            self.assertEqual(falcon.HTTP_201, self.srmock.status)
 
     def test_put_raises_if_missing_fields(self):
-        path = self.url_prefix + '/pools/' + str(uuid.uuid1())
+        path = self.url_prefix + '/pools/' + uuidutils.generate_uuid()
         self.simulate_put(path, body=jsonutils.dumps({'weight': 100}))
-        self.assertEqual(self.srmock.status, falcon.HTTP_400)
+        self.assertEqual(falcon.HTTP_400, self.srmock.status)
 
         self.simulate_put(path,
                           body=jsonutils.dumps(
                               {'uri': self.mongodb_url}))
-        self.assertEqual(self.srmock.status, falcon.HTTP_400)
+        self.assertEqual(falcon.HTTP_400, self.srmock.status)
 
     @ddt.data(-1, 2**32+1, 'big')
     def test_put_raises_if_invalid_weight(self, weight):
-        path = self.url_prefix + '/pools/' + str(uuid.uuid1())
+        path = self.url_prefix + '/pools/' + uuidutils.generate_uuid()
         doc = {'weight': weight, 'uri': 'a'}
         self.simulate_put(path,
                           body=jsonutils.dumps(doc))
-        self.assertEqual(self.srmock.status, falcon.HTTP_400)
+        self.assertEqual(falcon.HTTP_400, self.srmock.status)
 
     @ddt.data(-1, 2**32+1, [], 'localhost:27017')
     def test_put_raises_if_invalid_uri(self, uri):
-        path = self.url_prefix + '/pools/' + str(uuid.uuid1())
+        path = self.url_prefix + '/pools/' + uuidutils.generate_uuid()
         self.simulate_put(path,
                           body=jsonutils.dumps({'weight': 1, 'uri': uri}))
-        self.assertEqual(self.srmock.status, falcon.HTTP_400)
+        self.assertEqual(falcon.HTTP_400, self.srmock.status)
 
     @ddt.data(-1, 'wee', [])
     def test_put_raises_if_invalid_options(self, options):
-        path = self.url_prefix + '/pools/' + str(uuid.uuid1())
+        path = self.url_prefix + '/pools/' + uuidutils.generate_uuid()
         doc = {'weight': 1, 'uri': 'a', 'options': options}
         self.simulate_put(path, body=jsonutils.dumps(doc))
-        self.assertEqual(self.srmock.status, falcon.HTTP_400)
+        self.assertEqual(falcon.HTTP_400, self.srmock.status)
 
     def test_put_existing_overwrites(self):
         # NOTE(cabrera): setUp creates default pool
         expect = self.doc
         self.simulate_put(self.pool,
                           body=jsonutils.dumps(expect))
-        self.assertEqual(self.srmock.status, falcon.HTTP_201)
+        self.assertEqual(falcon.HTTP_201, self.srmock.status)
 
         result = self.simulate_get(self.pool)
-        self.assertEqual(self.srmock.status, falcon.HTTP_200)
+        self.assertEqual(falcon.HTTP_200, self.srmock.status)
         doc = jsonutils.loads(result[0])
-        self.assertEqual(doc['weight'], expect['weight'])
-        self.assertEqual(doc['uri'], expect['uri'])
+        self.assertEqual(expect['weight'], doc['weight'])
+        self.assertEqual(expect['uri'], doc['uri'])
 
     def test_delete_works(self):
         self.simulate_delete(self.pool)
-        self.assertEqual(self.srmock.status, falcon.HTTP_204)
+        self.assertEqual(falcon.HTTP_204, self.srmock.status)
 
         self.simulate_get(self.pool)
-        self.assertEqual(self.srmock.status, falcon.HTTP_404)
+        self.assertEqual(falcon.HTTP_404, self.srmock.status)
 
     def test_get_nonexisting_raises_404(self):
         self.simulate_get(self.url_prefix + '/pools/nonexisting')
-        self.assertEqual(self.srmock.status, falcon.HTTP_404)
+        self.assertEqual(falcon.HTTP_404, self.srmock.status)
 
     def _pool_expect(self, pool, xhref, xweight, xuri):
         self.assertIn('href', pool)
         self.assertIn('name', pool)
-        self.assertEqual(pool['href'], xhref)
+        self.assertEqual(xhref, pool['href'])
         self.assertIn('weight', pool)
-        self.assertEqual(pool['weight'], xweight)
+        self.assertEqual(xweight, pool['weight'])
         self.assertIn('uri', pool)
 
         # NOTE(dynarro): we are using startwith because we are adding to
@@ -173,7 +174,7 @@ class TestPoolsMongoDB(base.V1Base):
 
     def test_get_works(self):
         result = self.simulate_get(self.pool)
-        self.assertEqual(self.srmock.status, falcon.HTTP_200)
+        self.assertEqual(falcon.HTTP_200, self.srmock.status)
         pool = jsonutils.loads(result[0])
         self._pool_expect(pool, self.pool, self.doc['weight'],
                           self.doc['uri'])
@@ -181,30 +182,30 @@ class TestPoolsMongoDB(base.V1Base):
     def test_detailed_get_works(self):
         result = self.simulate_get(self.pool,
                                    query_string='detailed=True')
-        self.assertEqual(self.srmock.status, falcon.HTTP_200)
+        self.assertEqual(falcon.HTTP_200, self.srmock.status)
         pool = jsonutils.loads(result[0])
         self._pool_expect(pool, self.pool, self.doc['weight'],
                           self.doc['uri'])
         self.assertIn('options', pool)
-        self.assertEqual(pool['options'], {})
+        self.assertEqual({}, pool['options'])
 
     def test_patch_raises_if_missing_fields(self):
         self.simulate_patch(self.pool,
                             body=jsonutils.dumps({'location': 1}))
-        self.assertEqual(self.srmock.status, falcon.HTTP_400)
+        self.assertEqual(falcon.HTTP_400, self.srmock.status)
 
     def _patch_test(self, doc):
         self.simulate_patch(self.pool,
                             body=jsonutils.dumps(doc))
-        self.assertEqual(self.srmock.status, falcon.HTTP_200)
+        self.assertEqual(falcon.HTTP_200, self.srmock.status)
 
         result = self.simulate_get(self.pool,
                                    query_string='detailed=True')
-        self.assertEqual(self.srmock.status, falcon.HTTP_200)
+        self.assertEqual(falcon.HTTP_200, self.srmock.status)
         pool = jsonutils.loads(result[0])
         self._pool_expect(pool, self.pool, doc['weight'],
                           doc['uri'])
-        self.assertEqual(pool['options'], doc['options'])
+        self.assertEqual(doc['options'], pool['options'])
 
     def test_patch_works(self):
         doc = {'weight': 101,
@@ -223,31 +224,31 @@ class TestPoolsMongoDB(base.V1Base):
     def test_patch_raises_400_on_invalid_weight(self, weight):
         self.simulate_patch(self.pool,
                             body=jsonutils.dumps({'weight': weight}))
-        self.assertEqual(self.srmock.status, falcon.HTTP_400)
+        self.assertEqual(falcon.HTTP_400, self.srmock.status)
 
     @ddt.data(-1, 2**32+1, [], 'localhost:27017')
     def test_patch_raises_400_on_invalid_uri(self, uri):
         self.simulate_patch(self.pool,
                             body=jsonutils.dumps({'uri': uri}))
-        self.assertEqual(self.srmock.status, falcon.HTTP_400)
+        self.assertEqual(falcon.HTTP_400, self.srmock.status)
 
     @ddt.data(-1, 'wee', [])
     def test_patch_raises_400_on_invalid_options(self, options):
         self.simulate_patch(self.pool,
                             body=jsonutils.dumps({'options': options}))
-        self.assertEqual(self.srmock.status, falcon.HTTP_400)
+        self.assertEqual(falcon.HTTP_400, self.srmock.status)
 
     def test_patch_raises_404_if_pool_not_found(self):
         self.simulate_patch(self.url_prefix + '/pools/notexists',
                             body=jsonutils.dumps({'weight': 1}))
-        self.assertEqual(self.srmock.status, falcon.HTTP_404)
+        self.assertEqual(falcon.HTTP_404, self.srmock.status)
 
     def test_empty_listing(self):
         self.simulate_delete(self.pool)
         result = self.simulate_get(self.url_prefix + '/pools')
         results = jsonutils.loads(result[0])
-        self.assertEqual(self.srmock.status, falcon.HTTP_200)
-        self.assertTrue(len(results['pools']) == 0)
+        self.assertEqual(falcon.HTTP_200, self.srmock.status)
+        self.assertEqual(0, len(results['pools']))
         self.assertIn('links', results)
 
     def _listing_test(self, count=10, limit=10,
@@ -262,7 +263,7 @@ class TestPoolsMongoDB(base.V1Base):
         with pools(self, count, self.doc['uri']) as expected:
             result = self.simulate_get(self.url_prefix + '/pools',
                                        query_string=query)
-            self.assertEqual(self.srmock.status, falcon.HTTP_200)
+            self.assertEqual(falcon.HTTP_200, self.srmock.status)
             results = jsonutils.loads(result[0])
             self.assertIsInstance(results, dict)
             self.assertIn('pools', results)
@@ -273,28 +274,28 @@ class TestPoolsMongoDB(base.V1Base):
             self.assertEqual('next', link['rel'])
             href = falcon.uri.parse_query_string(link['href'].split('?')[1])
             self.assertIn('marker', href)
-            self.assertEqual(href['limit'], str(limit))
-            self.assertEqual(href['detailed'], str(detailed).lower())
+            self.assertEqual(str(limit), href['limit'])
+            self.assertEqual(str(detailed).lower(), href['detailed'])
 
             next_query_string = ('marker={marker}&limit={limit}'
                                  '&detailed={detailed}').format(**href)
             next_result = self.simulate_get(link['href'].split('?')[0],
                                             query_string=next_query_string)
-            self.assertEqual(self.srmock.status, falcon.HTTP_200)
+            self.assertEqual(falcon.HTTP_200, self.srmock.status)
 
             next_pool = jsonutils.loads(next_result[0])
             next_pool_list = next_pool['pools']
 
             self.assertIn('links', next_pool)
             if limit < count:
-                self.assertEqual(len(next_pool_list),
-                                 min(limit, count-limit))
+                self.assertEqual(min(limit, count-limit),
+                                 len(next_pool_list))
             else:
                 # NOTE(jeffrey4l): when limit >= count, there will be no
                 # pools in the 2nd page.
-                self.assertTrue(len(next_pool_list) == 0)
+                self.assertEqual(0, len(next_pool_list))
 
-            self.assertEqual(len(pool_list), min(limit, count))
+            self.assertEqual(min(limit, count), len(pool_list))
             for s in pool_list + next_pool_list:
                 # NOTE(flwang): It can't assumed that both sqlalchemy and
                 # mongodb can return query result with the same order. Just
@@ -307,7 +308,7 @@ class TestPoolsMongoDB(base.V1Base):
                 self._pool_expect(s, path, weight, self.doc['uri'])
                 if detailed:
                     self.assertIn('options', s)
-                    self.assertEqual(s['options'], expect[-1])
+                    self.assertEqual(expect[-1], s['options'])
                 else:
                     self.assertNotIn('options', s)
 
@@ -327,8 +328,8 @@ class TestPoolsMongoDB(base.V1Base):
         with pools(self, 10, self.doc['uri']) as expected:
             result = self.simulate_get(self.url_prefix + '/pools',
                                        query_string='marker=3')
-            self.assertEqual(self.srmock.status, falcon.HTTP_200)
+            self.assertEqual(falcon.HTTP_200, self.srmock.status)
             pool_list = jsonutils.loads(result[0])['pools']
-            self.assertEqual(len(pool_list), 6)
+            self.assertEqual(6, len(pool_list))
             path, weight = expected[4][:2]
             self._pool_expect(pool_list[0], path, weight, self.doc['uri'])
