@@ -44,6 +44,7 @@ def pool(test, name, weight, uri, group=None, options={}):
     path = test.url_prefix + '/pools/' + name
 
     test.simulate_put(path, body=jsonutils.dumps(doc))
+    test.addCleanup(test.simulate_delete, path)
 
     try:
         yield name, weight, uri, group, options
@@ -83,7 +84,7 @@ def pools(test, count, uri, group):
 
 
 @ddt.ddt
-class TestPoolsMongoDB(base.V2Base):
+class TestPoolsMongoDB(base.V1_1Base):
 
     config_file = 'wsgi_mongodb_pooled.conf'
 
@@ -140,13 +141,6 @@ class TestPoolsMongoDB(base.V2Base):
         self.simulate_put(path, body=jsonutils.dumps(doc))
         self.assertEqual(falcon.HTTP_400, self.srmock.status)
 
-    def test_put_same_database_uri(self):
-        # NOTE(cabrera): setUp creates default pool
-        expect = self.doc
-        path = self.url_prefix + '/pools/' + uuidutils.generate_uuid()
-        self.simulate_put(path, body=jsonutils.dumps(expect))
-        self.assertEqual(falcon.HTTP_409, self.srmock.status)
-
     def test_put_existing_overwrites(self):
         # NOTE(cabrera): setUp creates default pool
         expect = self.doc
@@ -220,12 +214,9 @@ class TestPoolsMongoDB(base.V2Base):
         self.assertEqual(falcon.HTTP_400, self.srmock.status)
 
     def _patch_test(self, doc):
-        result = self.simulate_patch(self.pool,
-                                     body=jsonutils.dumps(doc))
+        self.simulate_patch(self.pool,
+                            body=jsonutils.dumps(doc))
         self.assertEqual(falcon.HTTP_200, self.srmock.status)
-        updated_pool = jsonutils.loads(result[0])
-        self._pool_expect(updated_pool, self.pool, doc['weight'],
-                          doc['uri'])
 
         result = self.simulate_get(self.pool,
                                    query_string='detailed=True')
@@ -245,8 +236,7 @@ class TestPoolsMongoDB(base.V2Base):
         doc = {'weight': 101,
                'uri': self.mongodb_url,
                'options': {'a': 1},
-               'location': 100,
-               'partition': 'taco'}
+               'location': 100, 'partition': 'taco'}
         self._patch_test(doc)
 
     @ddt.data(-1, 2**32+1, 'big')
@@ -362,11 +352,3 @@ class TestPoolsMongoDB(base.V2Base):
             self.assertEqual(6, len(pool_list))
             path, weight = expected[4][:2]
             self._pool_expect(pool_list[0], path, weight, self.doc['uri'])
-
-    def test_listing_error_with_invalid_limit(self):
-        self.simulate_delete(self.pool)
-        query = 'limit={0}&detailed={1}'.format(0, True)
-
-        with pools(self, 10, self.doc['uri'], 'my-group'):
-            self.simulate_get(self.url_prefix + '/pools', query_string=query)
-            self.assertEqual(falcon.HTTP_400, self.srmock.status)
