@@ -23,6 +23,7 @@ from zaqar import tests as testing
 from zaqar.tests.unit.transport.wsgi import base
 
 
+# NOTE(gengchc2): remove pool_group in Rocky release.
 @contextlib.contextmanager
 def flavor(test, name, pool_group):
     """A context manager for constructing a flavor for use in testing.
@@ -137,6 +138,8 @@ class TestFlavorsMongoDB(base.V2Base):
         doc = {'pool_group': self.pool_group}
         self.simulate_put(path, body=jsonutils.dumps(doc))
         self.assertEqual(falcon.HTTP_201, self.srmock.status)
+        # NOTE(gengchc2): Delete it, otherwise exist garbage flavor.
+        self.simulate_delete(path)
 
     def test_put_existing_overwrites(self):
         # NOTE(cabrera): setUp creates default flavor
