@@ -30,10 +30,15 @@ _GENERAL_TRANSPORT_OPTIONS = (
 _RESOURCE_DEFAULTS = (
     cfg.IntOpt('default_message_ttl', default=3600,
                help=('Defines how long a message will be accessible.')),
+    cfg.IntOpt('default_message_delay', default=0,
+               help=('Defines the defautl value for queue delay seconds.'
+                     'The 0 means the delayed queues feature is close.')),
     cfg.IntOpt('default_claim_ttl', default=300,
                help=('Defines how long a message will be in claimed state.')),
     cfg.IntOpt('default_claim_grace', default=60,
-               help=('Defines the message grace period in seconds.'))
+               help=('Defines the message grace period in seconds.')),
+    cfg.IntOpt('default_subscription_ttl', default=3600,
+               help=('Defines how long a subscription will be available.')),
 )
 
 _TRANSPORT_GROUP = 'transport'
@@ -66,6 +71,10 @@ class ResourceDefaults(object):
     def claim_grace(self):
         return self._defaults.default_claim_grace
 
+    @property
+    def subscription_ttl(self):
+        return self._defaults.default_subscription_ttl
+
 
 @six.add_metaclass(abc.ABCMeta)
 class DriverBase(object):
@@ -76,7 +85,7 @@ class DriverBase(object):
     :param storage: The storage driver
     :type storage: zaqar.storage.base.DataDriverBase
     :param cache: caching object
-    :type cache: zaqar.openstack.common.cache.backends.BaseCache
+    :type cache: dogpile.cache.region.CacheRegion
     :param control: Storage driver to handle the control plane
     :type control: zaqar.storage.base.ControlDriverBase
     """
