@@ -21,11 +21,14 @@ from oslo_config import cfg
 from oslo_utils import timeutils
 import six
 
+from zaqar.common import consts
 from zaqar.i18n import _
 
+
 MIN_MESSAGE_TTL = 60
 MIN_CLAIM_TTL = 60
 MIN_CLAIM_GRACE = 60
+MIN_DELAY_TTL = 0
 MIN_SUBSCRIPTION_TTL = 60
 _PURGBLE_RESOURCE_TYPES = {'messages', 'subscriptions'}
 
@@ -66,6 +69,9 @@ _TRANSPORT_LIMITS_OPTIONS = (
                deprecated_group='limits:transport',
                help='Maximum amount of time a message will be available.'),
 
+    cfg.IntOpt('max_message_delay', default=900,
+               help='Maximum delay seconds for messages can be claimed.'),
+
     cfg.IntOpt('max_claim_ttl', default=43200,
                deprecated_name='claim_ttl_max',
                deprecated_group='limits:transport',
@@ -249,11 +255,11 @@ class Validator(object):
                     if retry_value and not isinstance(retry_value, str):
                         msg = _('retry_backoff_function must be a string.')
                         raise ValidationFailed(msg)
-                    # TODO(wanghao): Now we only support linear function.
-                    # This will be removed after we support more functions.
-                    if retry_value and retry_value != 'linear':
-                        msg = _('retry_backoff_function only supports linear '
-                                'now.')
+                    # Now we support linear, arithmetic, exponential
+                    # and geometric retry backoff function.
+                    fun = {'linear', 'arithmetic', 'exponential', 'geometric'}
+                    if retry_value and retry_value not in fun:
+                        msg = _('invalid retry_backoff_function.')
                         raise ValidationFailed(msg)
                 elif key == 'ignore_subscription_override':
                     if retry_value and not isinstance(retry_value, bool):
@@ -264,6 +270,16 @@ class Validator(object):
                     if retry_value and not isinstance(retry_value, int):
                         msg = _('Retry policy: %s must be a integer.') % key
                         raise ValidationFailed(msg)
+            min_delay = retry_policy.get('minimum_delay',
+                                         consts.MINIMUM_DELAY)
+            max_delay = retry_policy.get('maximum_delay',
+                                         consts.MAXIMUM_DELAY)
+            if max_delay < min_delay:
+                msg = _('minimum_delay must less than maximum_delay.')
+                raise ValidationFailed(msg)
+            if ((max_delay - min_delay) < 2*consts.LINEAR_INTERVAL):
+                msg = _('invalid minimum_delay and maximum_delay.')
+                raise ValidationFailed(msg)
 
     def queue_patching(self, request, changes):
         washed_changes = []
@@ -338,7 +354,7 @@ class Validator(object):
             msg = _(u'_default_message_ttl must be integer.')
             raise ValidationFailed(msg)
 
-        if queue_default_ttl:
+        if queue_default_ttl is not None:
             if not (MIN_MESSAGE_TTL <= queue_default_ttl <=
                     self._limits_conf.max_message_ttl):
                 msg = _(u'_default_message_ttl can not exceed {0} '
@@ -352,7 +368,7 @@ class Validator(object):
             msg = _(u'_max_messages_post_size must be integer.')
             raise ValidationFailed(msg)
 
-        if queue_max_msg_size:
+        if queue_max_msg_size is not None:
             if not (0 < queue_max_msg_size <=
                     self._limits_conf.max_messages_post_size):
                 raise ValidationFailed(
@@ -370,13 +386,28 @@ class Validator(object):
             msg = _(u'_dead_letter_queue_messages_ttl must be integer.')
             raise ValidationFailed(msg)
 
-        if dlq_ttl and not (MIN_MESSAGE_TTL <= dlq_ttl <=
-                            self._limits_conf.max_message_ttl):
+        if dlq_ttl is not None and not (MIN_MESSAGE_TTL <= dlq_ttl <=
+                                        self._limits_conf.max_message_ttl):
             msg = _(u'The TTL for a message may not exceed {0} seconds, '
                     'and must be at least {1} seconds long.')
             raise ValidationFailed(msg, self._limits_conf.max_message_ttl,
                                    MIN_MESSAGE_TTL)
 
+        queue_delay = queue_metadata.get('_default_message_delay',
+                                         None)
+        if queue_delay and not isinstance(queue_delay, int):
+            msg = _(u'_default_message_delay must be integer.')
+            raise ValidationFailed(msg)
+
+        if queue_delay is not None:
+            if not (MIN_DELAY_TTL <= queue_delay <=
+                    self._limits_conf.max_message_delay):
+                msg = _(u'The TTL can not exceed {0} seconds, and must '
+                        'be at least {1} seconds long.')
+                raise ValidationFailed(
+                    msg, self._limits_conf.max_message_delay,
+                    MIN_DELAY_TTL)
+
         self._validate_retry_policy(queue_metadata)
 
     def queue_purging(self, document):
@@ -454,6 +485,17 @@ class Validator(object):
             raise ValidationFailed(
                 msg, self._limits_conf.max_message_ttl, MIN_MESSAGE_TTL)
 
+        delay = message.get('delay', 0)
+
+        if not (MIN_DELAY_TTL <= delay <=
+                self._limits_conf.max_message_delay):
+            msg = _(u'The Delay TTL for a message may not exceed {0} seconds,'
+                    'and must be at least {1} seconds long.')
+
+            raise ValidationFailed(
+                msg, self._limits_conf.max_message_delay,
+                MIN_DELAY_TTL)
+
     def message_listing(self, limit=None, **kwargs):
         """Restrictions involving a list of messages.
 
