@@ -14,22 +14,23 @@
 # limitations under the License.
 
 from distutils import version as d_version
+import falcon
+import six
+import socket
 from wsgiref import simple_server
 
-import falcon
 from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_utils import netutils
-import six
-import socket
 
 from zaqar.common import decorators
 from zaqar.common.transport.wsgi import helpers
 from zaqar.i18n import _
-from zaqar import profile
 from zaqar import transport
 from zaqar.transport import acl
-from zaqar.transport import auth
+from zaqar.transport.middleware import auth
+from zaqar.transport.middleware import cors
+from zaqar.transport.middleware import profile
 from zaqar.transport import validation
 from zaqar.transport.wsgi import v1_0
 from zaqar.transport.wsgi import v1_1
@@ -37,8 +38,9 @@ from zaqar.transport.wsgi import v2_0
 from zaqar.transport.wsgi import version
 
 _WSGI_OPTIONS = (
-    cfg.IPOpt('bind', default='127.0.0.1',
-              help='Address on which the self-hosting server will listen.'),
+    cfg.HostAddressOpt('bind', default='127.0.0.1',
+                       help='Address on which the self-hosting server will '
+                            'listen.'),
 
     cfg.PortOpt('port', default=8888,
                 help='Port on which the self-hosting server will listen.'),
@@ -152,6 +154,10 @@ class Driver(transport.DriverBase):
 
         self.app = auth.SignedHeadersAuth(self.app, auth_app)
 
+        # NOTE(wangxiyuan): Install CORS, this middleware should be called
+        # before Keystone auth.
+        self.app = cors.install_cors(self.app, auth_app, self._conf)
+
         acl.setup_policy(self._conf)
 
     def _error_handler(self, exc, request, response, params):
