@@ -15,33 +15,32 @@
 from oslo_log import log as logging
 
 from zaqar.common import decorators
-from zaqar.transport.wsgi.v1_1 import claims
-from zaqar.transport.wsgi.v1_1 import flavors
-from zaqar.transport.wsgi.v1_1 import health
-from zaqar.transport.wsgi.v1_1 import homedoc
-from zaqar.transport.wsgi.v1_1 import messages
-from zaqar.transport.wsgi.v1_1 import ping
-from zaqar.transport.wsgi.v1_1 import pools
-from zaqar.transport.wsgi.v1_1 import queues
-from zaqar.transport.wsgi.v1_1 import stats
+from zaqar.transport.wsgi.v1_0 import claims
+from zaqar.transport.wsgi.v1_0 import health
+from zaqar.transport.wsgi.v1_0 import homedoc
+from zaqar.transport.wsgi.v1_0 import messages
+from zaqar.transport.wsgi.v1_0 import metadata
+from zaqar.transport.wsgi.v1_0 import pools
+from zaqar.transport.wsgi.v1_0 import queues
+from zaqar.transport.wsgi.v1_0 import stats
 
 
 LOG = logging.getLogger(__name__)
 
 
 VERSION = {
-    'id': '1.1',
+    'id': '1',
     'status': 'DEPRECATED',
-    'updated': '2016-7-29T02:22:47Z',
+    'updated': '2014-9-11T17:47:05Z',
     'media-types': [
         {
             'base': 'application/json',
-            'type': 'application/vnd.openstack.messaging-v1_1+json'
+            'type': 'application/vnd.openstack.messaging-v1+json'
         }
     ],
     'links': [
         {
-            'href': '/v1.1/',
+            'href': '/v1/',
             'rel': 'self'
         }
     ]
@@ -50,39 +49,33 @@ VERSION = {
 
 @decorators.api_version_manager(VERSION)
 def public_endpoints(driver, conf):
-    LOG.warning('Zaqar\'s API version 1.1 will enter deprecation during the '
-                'Newton cycle. As part of that, it will be marked as '
-                'deprecated and it will be turned off by default')
-
     queue_controller = driver._storage.queue_controller
     message_controller = driver._storage.message_controller
     claim_controller = driver._storage.claim_controller
 
-    defaults = driver._defaults
-
     return [
         # Home
         ('/',
-         homedoc.Resource(conf)),
+         homedoc.Resource()),
 
         # Queues Endpoints
         ('/queues',
          queues.CollectionResource(driver._validate,
                                    queue_controller)),
         ('/queues/{queue_name}',
-         queues.ItemResource(driver._validate,
-                             queue_controller,
+         queues.ItemResource(queue_controller,
                              message_controller)),
         ('/queues/{queue_name}/stats',
          stats.Resource(queue_controller)),
+        ('/queues/{queue_name}/metadata',
+         metadata.Resource(driver._wsgi_conf, driver._validate,
+                           queue_controller)),
 
         # Messages Endpoints
         ('/queues/{queue_name}/messages',
          messages.CollectionResource(driver._wsgi_conf,
                                      driver._validate,
-                                     message_controller,
-                                     queue_controller,
-                                     defaults.message_ttl)),
+                                     message_controller)),
         ('/queues/{queue_name}/messages/{message_id}',
          messages.ItemResource(message_controller)),
 
@@ -90,44 +83,28 @@ def public_endpoints(driver, conf):
         ('/queues/{queue_name}/claims',
          claims.CollectionResource(driver._wsgi_conf,
                                    driver._validate,
-                                   claim_controller,
-                                   defaults.claim_ttl,
-                                   defaults.claim_grace)),
+                                   claim_controller)),
         ('/queues/{queue_name}/claims/{claim_id}',
          claims.ItemResource(driver._wsgi_conf,
                              driver._validate,
-                             claim_controller,
-                             defaults.claim_ttl,
-                             defaults.claim_grace)),
+                             claim_controller)),
 
-        # Ping
-        ('/ping',
-         ping.Resource(driver._storage))
+        # Health
+        ('/health',
+         health.Resource(driver._storage))
     ]
 
 
 @decorators.api_version_manager(VERSION)
 def private_endpoints(driver, conf):
+    if not conf.pooling:
+        return []
 
-    catalogue = [
-        # Health
-        ('/health',
-         health.Resource(driver._storage)),
+    pools_controller = driver._control.pools_controller
+
+    return [
+        ('/pools',
+         pools.Listing(pools_controller)),
+        ('/pools/{pool}',
+         pools.Resource(pools_controller)),
     ]
-
-    if conf.pooling:
-        pools_controller = driver._control.pools_controller
-        flavors_controller = driver._control.flavors_controller
-
-        catalogue.extend([
-            ('/pools',
-             pools.Listing(pools_controller)),
-            ('/pools/{pool}',
-             pools.Resource(pools_controller)),
-            ('/flavors',
-             flavors.Listing(flavors_controller)),
-            ('/flavors/{flavor}',
-             flavors.Resource(flavors_controller)),
-        ])
-
-    return catalogue
