@@ -21,7 +21,6 @@ from zaqar.common import decorators
 from zaqar.common.transport.wsgi import helpers as wsgi_helpers
 from zaqar.i18n import _
 from zaqar.storage import errors as storage_errors
-from zaqar.transport import acl
 from zaqar.transport import utils
 from zaqar.transport import validation
 from zaqar.transport.wsgi import errors as wsgi_errors
@@ -38,7 +37,6 @@ class CollectionResource(object):
         '_wsgi_conf',
         '_validate',
         '_message_post_spec',
-        '_default_message_ttl'
     )
 
     def __init__(self, wsgi_conf, validate,
@@ -49,10 +47,9 @@ class CollectionResource(object):
         self._validate = validate
         self._message_controller = message_controller
         self._queue_controller = queue_controller
-        self._default_message_ttl = default_message_ttl
 
         self._message_post_spec = (
-            ('ttl', int, self._default_message_ttl),
+            ('ttl', int, default_message_ttl),
             ('body', '*', None),
         )
 
@@ -154,39 +151,12 @@ class CollectionResource(object):
     # ----------------------------------------------------------------------
 
     @decorators.TransportLog("Messages collection")
-    @acl.enforce("messages:create")
     def on_post(self, req, resp, project_id, queue_name):
         client_uuid = wsgi_helpers.get_client_uuid(req)
+
         try:
-            # NOTE(flwang): Replace 'exists' with 'get_metadata' won't impact
-            # the performance since both of them will call
-            # collection.find_one()
-            queue_meta = None
-            try:
-                queue_meta = self._queue_controller.get_metadata(queue_name,
-                                                                 project_id)
-            except storage_errors.DoesNotExist as ex:
-                self._validate.queue_identification(queue_name, project_id)
-                self._queue_controller.create(queue_name, project=project_id)
-                # NOTE(flwang): Queue is created in lazy mode, so no metadata
-                # set.
-                queue_meta = {}
-
-            queue_max_msg_size = queue_meta.get('_max_messages_post_size')
-            queue_default_ttl = queue_meta.get('_default_message_ttl')
-
-            # TODO(flwang): To avoid any unexpected regression issue, we just
-            # leave the _message_post_spec attribute of class as it's. It
-            # should be removed in Newton release.
-            if queue_default_ttl:
-                message_post_spec = (('ttl', int, queue_default_ttl),
-                                     ('body', '*', None),)
-            else:
-                message_post_spec = (('ttl', int, self._default_message_ttl),
-                                     ('body', '*', None),)
             # Place JSON size restriction before parsing
-            self._validate.message_length(req.content_length,
-                                          max_msg_post_size=queue_max_msg_size)
+            self._validate.message_length(req.content_length)
         except validation.ValidationFailed as ex:
             LOG.debug(ex)
             raise wsgi_errors.HTTPBadRequestAPI(six.text_type(ex))
@@ -199,12 +169,15 @@ class CollectionResource(object):
             raise wsgi_errors.HTTPBadRequestAPI(description)
 
         messages = wsgi_utils.sanitize(document['messages'],
-                                       message_post_spec,
+                                       self._message_post_spec,
                                        doctype=wsgi_utils.JSONArray)
 
         try:
             self._validate.message_posting(messages)
 
+            if not self._queue_controller.exists(queue_name, project_id):
+                self._queue_controller.create(queue_name, project=project_id)
+
             message_ids = self._message_controller.post(
                 queue_name,
                 messages=messages,
@@ -239,7 +212,6 @@ class CollectionResource(object):
         resp.status = falcon.HTTP_201
 
     @decorators.TransportLog("Messages collection")
-    @acl.enforce("messages:get_all")
     def on_get(self, req, resp, project_id, queue_name):
         ids = req.get_param_as_list('ids')
 
@@ -265,7 +237,6 @@ class CollectionResource(object):
         # status defaults to 200
 
     @decorators.TransportLog("Messages collection")
-    @acl.enforce("messages:delete_all")
     def on_delete(self, req, resp, project_id, queue_name):
         ids = req.get_param_as_list('ids')
         pop_limit = req.get_param_as_int('pop')
@@ -332,7 +303,6 @@ class ItemResource(object):
         self._message_controller = message_controller
 
     @decorators.TransportLog("Messages item")
-    @acl.enforce("messages:get")
     def on_get(self, req, resp, project_id, queue_name, message_id):
         try:
             message = self._message_controller.get(
@@ -359,7 +329,6 @@ class ItemResource(object):
         # status defaults to 200
 
     @decorators.TransportLog("Messages item")
-    @acl.enforce("messages:delete")
     def on_delete(self, req, resp, project_id, queue_name, message_id):
         error_title = _(u'Unable to delete')
 
