@@ -136,7 +136,8 @@ class Resource(object):
         self._validators = {
             'weight': validator_type(schema.patch_weight),
             'uri': validator_type(schema.patch_uri),
-            'group': validator_type(schema.patch_uri),
+            'group': validator_type(schema.patch_group),
+            'flavor': validator_type(schema.patch_flavor),
             'options': validator_type(schema.patch_options),
             'create': validator_type(schema.create)
         }
@@ -194,7 +195,8 @@ class Resource(object):
         try:
             self._ctrl.create(pool, weight=data['weight'],
                               uri=data['uri'],
-                              group=data.get('group'),
+                              group=data.get('group', None),
+                              flavor=data.get('flavor', None),
                               options=data.get('options', {}))
             response.status = falcon.HTTP_201
             response.location = request.path
@@ -234,9 +236,9 @@ class Resource(object):
         """Allows one to update a pool's weight, uri, and/or options.
 
         This method expects the user to submit a JSON object
-        containing at least one of: 'uri', 'weight', 'group', 'options'. If
-        none are found, the request is flagged as bad. There is also
-        strict format checking through the use of
+        containing at least one of: 'uri', 'weight', 'group', 'flavor',
+        'options'.If none are found, the request is flagged as bad.
+        There is also strict format checking through the use of
         jsonschema. Appropriate errors are returned in each case for
         badly formatted input.
 
@@ -246,11 +248,12 @@ class Resource(object):
         LOG.debug(u'PATCH pool - name: %s', pool)
         data = wsgi_utils.load(request)
 
-        EXPECT = ('weight', 'uri', 'group', 'options')
+        EXPECT = ('weight', 'uri', 'group', 'flavor', 'options')
         if not any([(field in data) for field in EXPECT]):
             LOG.debug(u'PATCH pool, bad params')
             raise wsgi_errors.HTTPBadRequestBody(
-                'One of `uri`, `weight`, `group`, or `options` needs '
+                'One of `uri`, `weight`, `group`, `flavor`,'
+                ' or `options` needs '
                 'to be specified'
             )
 
